import { eventHandler } from "h3";
import { overrideConfig, fetchReadme, decodeParams } from "../utils/queries.mjs";
import { useRuntimeConfig, cachedEventHandler } from "#imports";
const moduleConfig = useRuntimeConfig().github || {};
const handler = process.env.NODE_ENV === "development" || moduleConfig.disableCache ? eventHandler : cachedEventHandler;
export default handler(
  async (event) => {
    const query = decodeParams(event.context.params?.query);
    const githubConfig = overrideConfig(moduleConfig, query);
    if (!githubConfig.owner || !githubConfig.repo || !githubConfig.api) {
      return [];
    }
    const readme = await fetchReadme(githubConfig);
    const content = Buffer.from(readme.content ?? "", "base64").toString();
    if (moduleConfig.parseContents) {
      const markdown = await import("@nuxt/content/transformers/markdown").then((m) => m.default || m);
      return await markdown.parse(`${githubConfig.owner}:${githubConfig.repo}:readme.md`, content, {
        markdown: {
          remarkPlugins: {
            // Use current Github repository for remark-github plugin
            "remark-github": {
              repository: `${githubConfig.owner}/${githubConfig.repo}`
            }
          }
        }
      });
    }
    return content;
  },
  {
    maxAge: 60
    // cache for one minute
  }
);
