import { eventHandler } from "h3";
import { overrideConfig, decodeParams, fetchReleases, parseRelease } from "../../utils/queries.mjs";
import { useRuntimeConfig, cachedEventHandler } from "#imports";
const moduleConfig = useRuntimeConfig().github || {};
const handler = process.env.NODE_ENV === "development" || moduleConfig.disableCache ? eventHandler : cachedEventHandler;
export default handler(
  async (event) => {
    const query = decodeParams(event.context.params?.query);
    const githubConfig = overrideConfig(moduleConfig, query);
    if (!githubConfig.owner || !githubConfig.repo || !githubConfig.api) {
      return [];
    }
    let releases = await fetchReleases(query, githubConfig);
    if (!releases) {
      return;
    }
    if (moduleConfig.parseContents) {
      if (Array.isArray(releases)) {
        releases = await Promise.all(releases.map((release) => parseRelease(release, githubConfig)));
      } else {
        return await parseRelease(releases, githubConfig);
      }
    }
    return (releases || []).sort((a, b) => a.v !== b.v ? b.v - a.v : a.date - b.date).filter(Boolean);
  },
  {
    maxAge: 60
    // cache for one minute
  }
);
